@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# IBM OpenAPI SDK Code Generator Version: 3.67.0-df2073a1-20230222-221157
+# IBM OpenAPI SDK Code Generator Version: 3.82.1-2082d402-20231115-195014
 
 """
 Search for resources with the global and shared resource properties repository that is
@@ -23,7 +23,7 @@ resources attributes, which categorize or classify resources. A resource is a ph
 logical component that can be created or reserved for an application or service instance.
 They are owned by resource providers, such as Cloud Foundry, IBM Kubernetes Service, or
 resource controller in IBM Cloud. Resources are uniquely identified by a Cloud Resource
-Name (CRN)  or by an IMS ID. The properties of a resource include tags and system
+Name (CRN) or by an IMS ID. The properties of a resource include tags and system
 properties. Both properties are defined in an IBM Cloud billing account, and span across
 many regions.
 
@@ -31,9 +31,8 @@ API Version: 2.0.1
 """
 
 from enum import Enum
-from typing import Dict, List
+from typing import Dict, List, Optional
 import json
-import logging
 
 from ibm_cloud_sdk_core import BaseService, DetailedResponse
 from ibm_cloud_sdk_core.authenticators.authenticator import Authenticator
@@ -87,21 +86,22 @@ class GlobalSearchV2(BaseService):
     def search(
         self,
         *,
-        query: str = None,
-        fields: List[str] = None,
-        search_cursor: str = None,
-        transaction_id: str = None,
-        account_id: str = None,
-        boundary: str = None,
-        limit: int = None,
-        timeout: int = None,
-        sort: List[str] = None,
-        is_deleted: str = None,
-        is_reclaimed: str = None,
-        is_public: str = None,
-        impersonate_user: str = None,
-        can_tag: str = None,
-        **kwargs
+        query: Optional[str] = None,
+        fields: Optional[List[str]] = None,
+        search_cursor: Optional[str] = None,
+        x_request_id: Optional[str] = None,
+        x_correlation_id: Optional[str] = None,
+        transaction_id: Optional[str] = None,
+        account_id: Optional[str] = None,
+        limit: Optional[int] = None,
+        timeout: Optional[int] = None,
+        sort: Optional[List[str]] = None,
+        is_deleted: Optional[str] = None,
+        is_reclaimed: Optional[str] = None,
+        is_public: Optional[str] = None,
+        impersonate_user: Optional[str] = None,
+        can_tag: Optional[str] = None,
+        **kwargs,
     ) -> DetailedResponse:
         """
         Find instances of resources (v3).
@@ -131,12 +131,27 @@ class GlobalSearchV2(BaseService):
                each call and that must be set on the subsequent call to get the next batch
                of items. If the search returns no items, then the search_cursor is not
                present in the response.
-        :param str transaction_id: (optional) An alphanumeric string that can be
-               used to trace a request across services. If not specified, it automatically
-               generated with the prefix "gst-".
+        :param str x_request_id: (optional) An alphanumeric string that is used to
+               trace the request. The value  may include ASCII alphanumerics and any of
+               following segment separators: space ( ), comma (,), hyphen, (-), and
+               underscore (_) and may have a length up to 1024 bytes. The value is
+               considered invalid and must be ignored if that value includes any other
+               character or is longer than 1024 bytes or is fewer than 8 characters. If
+               not specified or invalid, it is automatically replaced by a random (version
+               4) UUID.
+        :param str x_correlation_id: (optional) An alphanumeric string that is used
+               to trace the request as a part of a larger context: the same value is used
+               for downstream requests and retries of those requests. The value may
+               include ASCII alphanumerics and any of following segment separators: space
+               ( ), comma (,), hyphen, (-), and underscore (_) and may have a length up to
+               1024 bytes. The value is considered invalid and must be ignored if that
+               value includes any other character or is longer than 1024 bytes or is fewer
+               than 8 characters. If not specified or invalid, it is automatically
+               replaced by a random (version 4) UUID.
+        :param str transaction_id: (optional) Deprecated: An alphanumeric string
+               that can be used to trace a request across services. If not specified, it
+               automatically generated with the prefix "gst-".
         :param str account_id: (optional) The account ID to filter resources.
-        :param str boundary: (optional) The boundary where the search performs.
-               This parameter must be set only for the cross-account searches.
         :param int limit: (optional) The maximum number of hits to return. Defaults
                to 10.
         :param int timeout: (optional) A search timeout in milliseconds, bounding
@@ -174,16 +189,19 @@ class GlobalSearchV2(BaseService):
         """
 
         headers = {
+            'x-request-id': x_request_id,
+            'x-correlation-id': x_correlation_id,
             'transaction-id': transaction_id,
         }
         sdk_headers = get_sdk_headers(
-            service_name=self.DEFAULT_SERVICE_NAME, service_version='V2', operation_id='search'
+            service_name=self.DEFAULT_SERVICE_NAME,
+            service_version='V2',
+            operation_id='search',
         )
         headers.update(sdk_headers)
 
         params = {
             'account_id': account_id,
-            'boundary': boundary,
             'limit': limit,
             'timeout': timeout,
             'sort': convert_list(sort),
@@ -209,43 +227,13 @@ class GlobalSearchV2(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/resources/search'
-        request = self.prepare_request(method='POST', url=url, headers=headers, params=params, data=data)
-
-        response = self.send(request, **kwargs)
-        return response
-
-    #########################
-    # resourceTypes
-    #########################
-
-    def get_supported_types(self, **kwargs) -> DetailedResponse:
-        """
-        DEPRECATED. Get all GhoST indexes.
-
-        Retrieves a list of all GhoST indexes.
-
-        :param dict headers: A `dict` containing the request headers
-        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
-        :rtype: DetailedResponse with `dict` result representing a `SupportedTypesList` object
-
-        Deprecated: this method is deprecated and may be removed in a future release.
-        """
-
-        logging.warning('A deprecated operation has been invoked: get_supported_types')
-
-        headers = {}
-        sdk_headers = get_sdk_headers(
-            service_name=self.DEFAULT_SERVICE_NAME, service_version='V2', operation_id='get_supported_types'
+        request = self.prepare_request(
+            method='POST',
+            url=url,
+            headers=headers,
+            params=params,
+            data=data,
         )
-        headers.update(sdk_headers)
-
-        if 'headers' in kwargs:
-            headers.update(kwargs.get('headers'))
-            del kwargs['headers']
-        headers['Accept'] = 'application/json'
-
-        url = '/v2/resources/supported_types'
-        request = self.prepare_request(method='GET', url=url, headers=headers)
 
         response = self.send(request, **kwargs)
         return response
@@ -256,15 +244,6 @@ class SearchEnums:
     Enums for search parameters.
     """
 
-    class Boundary(str, Enum):
-        """
-        The boundary where the search performs. This parameter must be set only for the
-        cross-account searches.
-        """
-
-        GLOBAL = 'global'
-        US_REGULATED = 'us-regulated'
-
     class IsDeleted(str, Enum):
         """
         Determines if deleted documents should be included in result set or not. Possible
@@ -323,13 +302,17 @@ class ResultItem:
     A resource returned in a search result, which is identified by its `crn`. It contains
     other properties that depend on the resource type.
 
-    :attr str crn: Resource identifier in CRN format.
+    :param str crn: Resource identifier in CRN format.
     """
 
     # The set of defined properties for the class
     _properties = frozenset(['crn'])
 
-    def __init__(self, crn: str, **kwargs) -> None:
+    def __init__(
+        self,
+        crn: str,
+        **kwargs,
+    ) -> None:
         """
         Initialize a ResultItem object.
 
@@ -405,15 +388,21 @@ class ScanResult:
     """
     The search scan response.
 
-    :attr str search_cursor: (optional) The search cursor to use on all calls after
+    :param str search_cursor: (optional) The search cursor to use on all calls after
           the first one.
-    :attr int limit: Value of the limit parameter specified by the user.
-    :attr List[ResultItem] items: The array of results. Each item represents a
+    :param int limit: Value of the limit parameter specified by the user.
+    :param List[ResultItem] items: The array of results. Each item represents a
           resource. An empty array signals the end of the result set, which means there
           are no more results to fetch.
     """
 
-    def __init__(self, limit: int, items: List['ResultItem'], *, search_cursor: str = None) -> None:
+    def __init__(
+        self,
+        limit: int,
+        items: List['ResultItem'],
+        *,
+        search_cursor: Optional[str] = None,
+    ) -> None:
         """
         Initialize a ScanResult object.
 
@@ -483,57 +472,3 @@ class ScanResult:
     def __ne__(self, other: 'ScanResult') -> bool:
         """Return `true` when self and other are not equal, false otherwise."""
         return not self == other
-
-
-class SupportedTypesList:
-    """
-    A list of all GhoST indexes.
-
-    :attr List[str] supported_types: (optional) A list of all GhoST indexes.
-    """
-
-    def __init__(self, *, supported_types: List[str] = None) -> None:
-        """
-        Initialize a SupportedTypesList object.
-
-        :param List[str] supported_types: (optional) A list of all GhoST indexes.
-        """
-        self.supported_types = supported_types
-
-    @classmethod
-    def from_dict(cls, _dict: Dict) -> 'SupportedTypesList':
-        """Initialize a SupportedTypesList object from a json dictionary."""
-        args = {}
-        if 'supported_types' in _dict:
-            args['supported_types'] = _dict.get('supported_types')
-        return cls(**args)
-
-    @classmethod
-    def _from_dict(cls, _dict):
-        """Initialize a SupportedTypesList object from a json dictionary."""
-        return cls.from_dict(_dict)
-
-    def to_dict(self) -> Dict:
-        """Return a json dictionary representing this model."""
-        _dict = {}
-        if hasattr(self, 'supported_types') and self.supported_types is not None:
-            _dict['supported_types'] = self.supported_types
-        return _dict
-
-    def _to_dict(self):
-        """Return a json dictionary representing this model."""
-        return self.to_dict()
-
-    def __str__(self) -> str:
-        """Return a `str` version of this SupportedTypesList object."""
-        return json.dumps(self.to_dict(), indent=2)
-
-    def __eq__(self, other: 'SupportedTypesList') -> bool:
-        """Return `true` when self and other are equal, false otherwise."""
-        if not isinstance(other, self.__class__):
-            return False
-        return self.__dict__ == other.__dict__
-
-    def __ne__(self, other: 'SupportedTypesList') -> bool:
-        """Return `true` when self and other are not equal, false otherwise."""
-        return not self == other
