@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# IBM OpenAPI SDK Code Generator Version: 3.63.0-5dae26c1-20230111-193039
+# IBM OpenAPI SDK Code Generator Version: 3.82.1-2082d402-20231115-195014
 
 """
 Manage your tags with the Tagging API in IBM Cloud. You can attach, detach, delete, or
@@ -30,7 +30,7 @@ API Version: 1.2.0
 """
 
 from enum import Enum
-from typing import Dict, List
+from typing import Dict, List, Optional
 import json
 
 from ibm_cloud_sdk_core import BaseService, DetailedResponse
@@ -85,19 +85,20 @@ class GlobalTaggingV1(BaseService):
     def list_tags(
         self,
         *,
-        transaction_id: str = None,
-        impersonate_user: str = None,
-        account_id: str = None,
-        tag_type: str = None,
-        full_data: bool = None,
-        providers: List[str] = None,
-        attached_to: str = None,
-        offset: int = None,
-        limit: int = None,
-        timeout: int = None,
-        order_by_name: str = None,
-        attached_only: bool = None,
-        **kwargs
+        x_request_id: Optional[str] = None,
+        x_correlation_id: Optional[str] = None,
+        transaction_id: Optional[str] = None,
+        account_id: Optional[str] = None,
+        tag_type: Optional[str] = None,
+        full_data: Optional[bool] = None,
+        providers: Optional[List[str]] = None,
+        attached_to: Optional[str] = None,
+        offset: Optional[int] = None,
+        limit: Optional[int] = None,
+        timeout: Optional[int] = None,
+        order_by_name: Optional[str] = None,
+        attached_only: Optional[bool] = None,
+        **kwargs,
     ) -> DetailedResponse:
         """
         Get all tags.
@@ -105,11 +106,26 @@ class GlobalTaggingV1(BaseService):
         Lists all tags that are in a billing account. Use the `attached_to` parameter to
         return the list of tags that are attached to the specified resource.
 
-        :param str transaction_id: (optional) An alphanumeric string that can be
-               used to trace a request across services. If not specified, it automatically
-               generated with the prefix "gst-".
-        :param str impersonate_user: (optional) The user on whose behalf the get
-               operation must be performed (_for administrators only_).
+        :param str x_request_id: (optional) An alphanumeric string that is used to
+               trace the request. The value  may include ASCII alphanumerics and any of
+               following segment separators: space ( ), comma (,), hyphen, (-), and
+               underscore (_) and may have a length up to 1024 bytes. The value is
+               considered invalid and must be ignored if that value includes any other
+               character or is longer than 1024 bytes or is fewer than 8 characters. If
+               not specified or invalid, it is automatically replaced by a random (version
+               4) UUID.
+        :param str x_correlation_id: (optional) An alphanumeric string that is used
+               to trace the request as a part of a larger context: the same value is used
+               for downstream requests and retries of those requests. The value may
+               include ASCII alphanumerics and any of following segment separators: space
+               ( ), comma (,), hyphen, (-), and underscore (_) and may have a length up to
+               1024 bytes. The value is considered invalid and must be ignored if that
+               value includes any other character or is longer than 1024 bytes or is fewer
+               than 8 characters. If not specified or invalid, it is automatically
+               replaced by a random (version 4) UUID.
+        :param str transaction_id: (optional) Deprecated: An alphanumeric string
+               that can be used to trace a request across services. If not specified, it
+               automatically generated with the prefix "gst-".
         :param str account_id: (optional) The ID of the billing account to list the
                tags for. If it is not set, then it is taken from the authorization token.
                This parameter is required if `tag_type` is set to `service`.
@@ -145,15 +161,18 @@ class GlobalTaggingV1(BaseService):
         """
 
         headers = {
+            'x-request-id': x_request_id,
+            'x-correlation-id': x_correlation_id,
             'transaction-id': transaction_id,
         }
         sdk_headers = get_sdk_headers(
-            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='list_tags'
+            service_name=self.DEFAULT_SERVICE_NAME,
+            service_version='V1',
+            operation_id='list_tags',
         )
         headers.update(sdk_headers)
 
         params = {
-            'impersonate_user': impersonate_user,
             'account_id': account_id,
             'tag_type': tag_type,
             'full_data': full_data,
@@ -172,7 +191,12 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags'
-        request = self.prepare_request(method='GET', url=url, headers=headers, params=params)
+        request = self.prepare_request(
+            method='GET',
+            url=url,
+            headers=headers,
+            params=params,
+        )
 
         response = self.send(request, **kwargs)
         return response
@@ -181,11 +205,12 @@ class GlobalTaggingV1(BaseService):
         self,
         tag_names: List[str],
         *,
-        impersonate_user: str = None,
-        transaction_id: str = None,
-        account_id: str = None,
-        tag_type: str = None,
-        **kwargs
+        x_request_id: Optional[str] = None,
+        x_correlation_id: Optional[str] = None,
+        transaction_id: Optional[str] = None,
+        account_id: Optional[str] = None,
+        tag_type: Optional[str] = None,
+        **kwargs,
     ) -> DetailedResponse:
         """
         Create an access management tag.
@@ -197,14 +222,28 @@ class GlobalTaggingV1(BaseService):
         are attached for the first time to a resource.
 
         :param List[str] tag_names: An array of tag names to create.
-        :param str impersonate_user: (optional) The user on whose behalf the create
-               operation must be performed (_for administrators only_).
-        :param str transaction_id: (optional) An alphanumeric string that can be
-               used to trace a request across services. If not specified, it automatically
-               generated with the prefix "gst-".
+        :param str x_request_id: (optional) An alphanumeric string that is used to
+               trace the request. The value  may include ASCII alphanumerics and any of
+               following segment separators: space ( ), comma (,), hyphen, (-), and
+               underscore (_) and may have a length up to 1024 bytes. The value is
+               considered invalid and must be ignored if that value includes any other
+               character or is longer than 1024 bytes or is fewer than 8 characters. If
+               not specified or invalid, it is automatically replaced by a random (version
+               4) UUID.
+        :param str x_correlation_id: (optional) An alphanumeric string that is used
+               to trace the request as a part of a larger context: the same value is used
+               for downstream requests and retries of those requests. The value may
+               include ASCII alphanumerics and any of following segment separators: space
+               ( ), comma (,), hyphen, (-), and underscore (_) and may have a length up to
+               1024 bytes. The value is considered invalid and must be ignored if that
+               value includes any other character or is longer than 1024 bytes or is fewer
+               than 8 characters. If not specified or invalid, it is automatically
+               replaced by a random (version 4) UUID.
+        :param str transaction_id: (optional) Deprecated: An alphanumeric string
+               that can be used to trace a request across services. If not specified, it
+               automatically generated with the prefix "gst-".
         :param str account_id: (optional) The ID of the billing account where the
-               tag must be created. It is a required parameter if `impersonate_user` is
-               set.
+               tag must be created.
         :param str tag_type: (optional) The type of the tags you want to create.
                The only allowed value is `access`.
         :param dict headers: A `dict` containing the request headers
@@ -215,15 +254,18 @@ class GlobalTaggingV1(BaseService):
         if tag_names is None:
             raise ValueError('tag_names must be provided')
         headers = {
+            'x-request-id': x_request_id,
+            'x-correlation-id': x_correlation_id,
             'transaction-id': transaction_id,
         }
         sdk_headers = get_sdk_headers(
-            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='create_tag'
+            service_name=self.DEFAULT_SERVICE_NAME,
+            service_version='V1',
+            operation_id='create_tag',
         )
         headers.update(sdk_headers)
 
         params = {
-            'impersonate_user': impersonate_user,
             'account_id': account_id,
             'tag_type': tag_type,
         }
@@ -241,7 +283,13 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags'
-        request = self.prepare_request(method='POST', url=url, headers=headers, params=params, data=data)
+        request = self.prepare_request(
+            method='POST',
+            url=url,
+            headers=headers,
+            params=params,
+            data=data,
+        )
 
         response = self.send(request, **kwargs)
         return response
@@ -249,25 +297,41 @@ class GlobalTaggingV1(BaseService):
     def delete_tag_all(
         self,
         *,
-        transaction_id: str = None,
-        providers: str = None,
-        impersonate_user: str = None,
-        account_id: str = None,
-        tag_type: str = None,
-        **kwargs
+        x_request_id: Optional[str] = None,
+        x_correlation_id: Optional[str] = None,
+        transaction_id: Optional[str] = None,
+        providers: Optional[str] = None,
+        account_id: Optional[str] = None,
+        tag_type: Optional[str] = None,
+        **kwargs,
     ) -> DetailedResponse:
         """
         Delete all unused tags.
 
         Delete the tags that are not attached to any resource.
 
-        :param str transaction_id: (optional) An alphanumeric string that can be
-               used to trace a request across services. If not specified, it automatically
-               generated with the prefix "gst-".
+        :param str x_request_id: (optional) An alphanumeric string that is used to
+               trace the request. The value  may include ASCII alphanumerics and any of
+               following segment separators: space ( ), comma (,), hyphen, (-), and
+               underscore (_) and may have a length up to 1024 bytes. The value is
+               considered invalid and must be ignored if that value includes any other
+               character or is longer than 1024 bytes or is fewer than 8 characters. If
+               not specified or invalid, it is automatically replaced by a random (version
+               4) UUID.
+        :param str x_correlation_id: (optional) An alphanumeric string that is used
+               to trace the request as a part of a larger context: the same value is used
+               for downstream requests and retries of those requests. The value may
+               include ASCII alphanumerics and any of following segment separators: space
+               ( ), comma (,), hyphen, (-), and underscore (_) and may have a length up to
+               1024 bytes. The value is considered invalid and must be ignored if that
+               value includes any other character or is longer than 1024 bytes or is fewer
+               than 8 characters. If not specified or invalid, it is automatically
+               replaced by a random (version 4) UUID.
+        :param str transaction_id: (optional) Deprecated: An alphanumeric string
+               that can be used to trace a request across services. If not specified, it
+               automatically generated with the prefix "gst-".
         :param str providers: (optional) Select a provider. Supported values are
                `ghost` and `ims`.
-        :param str impersonate_user: (optional) The user on whose behalf the delete
-               all operation must be performed (_for administrators only_).
         :param str account_id: (optional) The ID of the billing account to delete
                the tags for. If it is not set, then it is taken from the authorization
                token. It is a required parameter if `tag_type` is set to `service`.
@@ -280,16 +344,19 @@ class GlobalTaggingV1(BaseService):
         """
 
         headers = {
+            'x-request-id': x_request_id,
+            'x-correlation-id': x_correlation_id,
             'transaction-id': transaction_id,
         }
         sdk_headers = get_sdk_headers(
-            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='delete_tag_all'
+            service_name=self.DEFAULT_SERVICE_NAME,
+            service_version='V1',
+            operation_id='delete_tag_all',
         )
         headers.update(sdk_headers)
 
         params = {
             'providers': providers,
-            'impersonate_user': impersonate_user,
             'account_id': account_id,
             'tag_type': tag_type,
         }
@@ -300,7 +367,12 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags'
-        request = self.prepare_request(method='DELETE', url=url, headers=headers, params=params)
+        request = self.prepare_request(
+            method='DELETE',
+            url=url,
+            headers=headers,
+            params=params,
+        )
 
         response = self.send(request, **kwargs)
         return response
@@ -309,12 +381,13 @@ class GlobalTaggingV1(BaseService):
         self,
         tag_name: str,
         *,
-        transaction_id: str = None,
-        providers: List[str] = None,
-        impersonate_user: str = None,
-        account_id: str = None,
-        tag_type: str = None,
-        **kwargs
+        x_request_id: Optional[str] = None,
+        x_correlation_id: Optional[str] = None,
+        transaction_id: Optional[str] = None,
+        providers: Optional[List[str]] = None,
+        account_id: Optional[str] = None,
+        tag_type: Optional[str] = None,
+        **kwargs,
     ) -> DetailedResponse:
         """
         Delete an unused tag.
@@ -323,14 +396,29 @@ class GlobalTaggingV1(BaseService):
         resource.
 
         :param str tag_name: The name of tag to be deleted.
-        :param str transaction_id: (optional) An alphanumeric string that can be
-               used to trace a request across services. If not specified, it automatically
-               generated with the prefix "gst-".
+        :param str x_request_id: (optional) An alphanumeric string that is used to
+               trace the request. The value  may include ASCII alphanumerics and any of
+               following segment separators: space ( ), comma (,), hyphen, (-), and
+               underscore (_) and may have a length up to 1024 bytes. The value is
+               considered invalid and must be ignored if that value includes any other
+               character or is longer than 1024 bytes or is fewer than 8 characters. If
+               not specified or invalid, it is automatically replaced by a random (version
+               4) UUID.
+        :param str x_correlation_id: (optional) An alphanumeric string that is used
+               to trace the request as a part of a larger context: the same value is used
+               for downstream requests and retries of those requests. The value may
+               include ASCII alphanumerics and any of following segment separators: space
+               ( ), comma (,), hyphen, (-), and underscore (_) and may have a length up to
+               1024 bytes. The value is considered invalid and must be ignored if that
+               value includes any other character or is longer than 1024 bytes or is fewer
+               than 8 characters. If not specified or invalid, it is automatically
+               replaced by a random (version 4) UUID.
+        :param str transaction_id: (optional) Deprecated: An alphanumeric string
+               that can be used to trace a request across services. If not specified, it
+               automatically generated with the prefix "gst-".
         :param List[str] providers: (optional) Select a provider. Supported values
                are `ghost` and `ims`. To delete tags both in Global Search and Tagging and
                in IMS, use `ghost,ims`.
-        :param str impersonate_user: (optional) The user on whose behalf the delete
-               operation must be performed (_for administrators only_).
         :param str account_id: (optional) The ID of the billing account to delete
                the tag for. It is a required parameter if `tag_type` is set to `service`,
                otherwise it is inferred from the authorization IAM token.
@@ -345,16 +433,19 @@ class GlobalTaggingV1(BaseService):
         if not tag_name:
             raise ValueError('tag_name must be provided')
         headers = {
+            'x-request-id': x_request_id,
+            'x-correlation-id': x_correlation_id,
             'transaction-id': transaction_id,
         }
         sdk_headers = get_sdk_headers(
-            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='delete_tag'
+            service_name=self.DEFAULT_SERVICE_NAME,
+            service_version='V1',
+            operation_id='delete_tag',
         )
         headers.update(sdk_headers)
 
         params = {
             'providers': convert_list(providers),
-            'impersonate_user': impersonate_user,
             'account_id': account_id,
             'tag_type': tag_type,
         }
@@ -368,7 +459,12 @@ class GlobalTaggingV1(BaseService):
         path_param_values = self.encode_path_vars(tag_name)
         path_param_dict = dict(zip(path_param_keys, path_param_values))
         url = '/v3/tags/{tag_name}'.format(**path_param_dict)
-        request = self.prepare_request(method='DELETE', url=url, headers=headers, params=params)
+        request = self.prepare_request(
+            method='DELETE',
+            url=url,
+            headers=headers,
+            params=params,
+        )
 
         response = self.send(request, **kwargs)
         return response
@@ -377,13 +473,14 @@ class GlobalTaggingV1(BaseService):
         self,
         resources: List['Resource'],
         *,
-        tag_name: str = None,
-        tag_names: List[str] = None,
-        transaction_id: str = None,
-        impersonate_user: str = None,
-        account_id: str = None,
-        tag_type: str = None,
-        **kwargs
+        tag_name: Optional[str] = None,
+        tag_names: Optional[List[str]] = None,
+        x_request_id: Optional[str] = None,
+        x_correlation_id: Optional[str] = None,
+        transaction_id: Optional[str] = None,
+        account_id: Optional[str] = None,
+        tag_type: Optional[str] = None,
+        **kwargs,
     ) -> DetailedResponse:
         """
         Attach tags.
@@ -396,11 +493,26 @@ class GlobalTaggingV1(BaseService):
                are attached.
         :param str tag_name: (optional) The name of the tag to attach.
         :param List[str] tag_names: (optional) An array of tag names to attach.
-        :param str transaction_id: (optional) An alphanumeric string that can be
-               used to trace a request across services. If not specified, it automatically
-               generated with the prefix "gst-".
-        :param str impersonate_user: (optional) The user on whose behalf the attach
-               operation must be performed (_for administrators only_).
+        :param str x_request_id: (optional) An alphanumeric string that is used to
+               trace the request. The value  may include ASCII alphanumerics and any of
+               following segment separators: space ( ), comma (,), hyphen, (-), and
+               underscore (_) and may have a length up to 1024 bytes. The value is
+               considered invalid and must be ignored if that value includes any other
+               character or is longer than 1024 bytes or is fewer than 8 characters. If
+               not specified or invalid, it is automatically replaced by a random (version
+               4) UUID.
+        :param str x_correlation_id: (optional) An alphanumeric string that is used
+               to trace the request as a part of a larger context: the same value is used
+               for downstream requests and retries of those requests. The value may
+               include ASCII alphanumerics and any of following segment separators: space
+               ( ), comma (,), hyphen, (-), and underscore (_) and may have a length up to
+               1024 bytes. The value is considered invalid and must be ignored if that
+               value includes any other character or is longer than 1024 bytes or is fewer
+               than 8 characters. If not specified or invalid, it is automatically
+               replaced by a random (version 4) UUID.
+        :param str transaction_id: (optional) Deprecated: An alphanumeric string
+               that can be used to trace a request across services. If not specified, it
+               automatically generated with the prefix "gst-".
         :param str account_id: (optional) The ID of the billing account of the
                tagged resource. It is a required parameter if `tag_type` is set to
                `service`. Otherwise, it is inferred from the authorization IAM token.
@@ -416,15 +528,18 @@ class GlobalTaggingV1(BaseService):
             raise ValueError('resources must be provided')
         resources = [convert_model(x) for x in resources]
         headers = {
+            'x-request-id': x_request_id,
+            'x-correlation-id': x_correlation_id,
             'transaction-id': transaction_id,
         }
         sdk_headers = get_sdk_headers(
-            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='attach_tag'
+            service_name=self.DEFAULT_SERVICE_NAME,
+            service_version='V1',
+            operation_id='attach_tag',
         )
         headers.update(sdk_headers)
 
         params = {
-            'impersonate_user': impersonate_user,
             'account_id': account_id,
             'tag_type': tag_type,
         }
@@ -444,7 +559,13 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags/attach'
-        request = self.prepare_request(method='POST', url=url, headers=headers, params=params, data=data)
+        request = self.prepare_request(
+            method='POST',
+            url=url,
+            headers=headers,
+            params=params,
+            data=data,
+        )
 
         response = self.send(request, **kwargs)
         return response
@@ -453,13 +574,14 @@ class GlobalTaggingV1(BaseService):
         self,
         resources: List['Resource'],
         *,
-        tag_name: str = None,
-        tag_names: List[str] = None,
-        transaction_id: str = None,
-        impersonate_user: str = None,
-        account_id: str = None,
-        tag_type: str = None,
-        **kwargs
+        tag_name: Optional[str] = None,
+        tag_names: Optional[List[str]] = None,
+        x_request_id: Optional[str] = None,
+        x_correlation_id: Optional[str] = None,
+        transaction_id: Optional[str] = None,
+        account_id: Optional[str] = None,
+        tag_type: Optional[str] = None,
+        **kwargs,
     ) -> DetailedResponse:
         """
         Detach tags.
@@ -470,13 +592,28 @@ class GlobalTaggingV1(BaseService):
                are detached.
         :param str tag_name: (optional) The name of the tag to detach.
         :param List[str] tag_names: (optional) An array of tag names to detach.
-        :param str transaction_id: (optional) An alphanumeric string that can be
-               used to trace a request across services. If not specified, it automatically
-               generated with the prefix "gst-".
-        :param str impersonate_user: (optional) The user on whose behalf the detach
-               operation must be performed (_for administrators only_).
+        :param str x_request_id: (optional) An alphanumeric string that is used to
+               trace the request. The value  may include ASCII alphanumerics and any of
+               following segment separators: space ( ), comma (,), hyphen, (-), and
+               underscore (_) and may have a length up to 1024 bytes. The value is
+               considered invalid and must be ignored if that value includes any other
+               character or is longer than 1024 bytes or is fewer than 8 characters. If
+               not specified or invalid, it is automatically replaced by a random (version
+               4) UUID.
+        :param str x_correlation_id: (optional) An alphanumeric string that is used
+               to trace the request as a part of a larger context: the same value is used
+               for downstream requests and retries of those requests. The value may
+               include ASCII alphanumerics and any of following segment separators: space
+               ( ), comma (,), hyphen, (-), and underscore (_) and may have a length up to
+               1024 bytes. The value is considered invalid and must be ignored if that
+               value includes any other character or is longer than 1024 bytes or is fewer
+               than 8 characters. If not specified or invalid, it is automatically
+               replaced by a random (version 4) UUID.
+        :param str transaction_id: (optional) Deprecated: An alphanumeric string
+               that can be used to trace a request across services. If not specified, it
+               automatically generated with the prefix "gst-".
         :param str account_id: (optional) The ID of the billing account of the
-               untagged resource.  It is a required parameter if `tag_type` is set to
+               untagged resource. It is a required parameter if `tag_type` is set to
                `service`, otherwise it is inferred from the authorization IAM token.
         :param str tag_type: (optional) The type of the tag. Supported values are
                `user`, `service` and `access`. `service` and `access` are not supported
@@ -490,15 +627,18 @@ class GlobalTaggingV1(BaseService):
             raise ValueError('resources must be provided')
         resources = [convert_model(x) for x in resources]
         headers = {
+            'x-request-id': x_request_id,
+            'x-correlation-id': x_correlation_id,
             'transaction-id': transaction_id,
         }
         sdk_headers = get_sdk_headers(
-            service_name=self.DEFAULT_SERVICE_NAME, service_version='V1', operation_id='detach_tag'
+            service_name=self.DEFAULT_SERVICE_NAME,
+            service_version='V1',
+            operation_id='detach_tag',
         )
         headers.update(sdk_headers)
 
         params = {
-            'impersonate_user': impersonate_user,
             'account_id': account_id,
             'tag_type': tag_type,
         }
@@ -518,7 +658,13 @@ class GlobalTaggingV1(BaseService):
         headers['Accept'] = 'application/json'
 
         url = '/v3/tags/detach'
-        request = self.prepare_request(method='POST', url=url, headers=headers, params=params, data=data)
+        request = self.prepare_request(
+            method='POST',
+            url=url,
+            headers=headers,
+            params=params,
+            data=data,
+        )
 
         response = self.send(request, **kwargs)
         return response
@@ -664,11 +810,15 @@ class CreateTagResults:
     """
     Results of a create tag(s) request.
 
-    :attr List[CreateTagResultsResultsItem] results: (optional) Array of results of
+    :param List[CreateTagResultsResultsItem] results: (optional) Array of results of
           a create_tag request.
     """
 
-    def __init__(self, *, results: List['CreateTagResultsResultsItem'] = None) -> None:
+    def __init__(
+        self,
+        *,
+        results: Optional[List['CreateTagResultsResultsItem']] = None,
+    ) -> None:
         """
         Initialize a CreateTagResults object.
 
@@ -726,12 +876,17 @@ class CreateTagResultsResultsItem:
     """
     CreateTagResultsResultsItem.
 
-    :attr str tag_name: (optional) The name of the tag created.
-    :attr bool is_error: (optional) true if the tag was not created (for example,
+    :param str tag_name: (optional) The name of the tag created.
+    :param bool is_error: (optional) true if the tag was not created (for example,
           the tag already exists).
     """
 
-    def __init__(self, *, tag_name: str = None, is_error: bool = None) -> None:
+    def __init__(
+        self,
+        *,
+        tag_name: Optional[str] = None,
+        is_error: Optional[bool] = None,
+    ) -> None:
         """
         Initialize a CreateTagResultsResultsItem object.
 
@@ -789,11 +944,15 @@ class DeleteTagResults:
     """
     Results of a delete_tag request.
 
-    :attr List[DeleteTagResultsItem] results: (optional) Array of results of a
+    :param List[DeleteTagResultsItem] results: (optional) Array of results of a
           delete_tag request.
     """
 
-    def __init__(self, *, results: List['DeleteTagResultsItem'] = None) -> None:
+    def __init__(
+        self,
+        *,
+        results: Optional[List['DeleteTagResultsItem']] = None,
+    ) -> None:
         """
         Initialize a DeleteTagResults object.
 
@@ -851,15 +1010,21 @@ class DeleteTagResultsItem:
     """
     Result of a delete_tag request.
 
-    :attr str provider: (optional) The provider of the tag.
-    :attr bool is_error: (optional) It is `true` if the operation exits with an
+    :param str provider: (optional) The provider of the tag.
+    :param bool is_error: (optional) It is `true` if the operation exits with an
           error (for example, the tag does not exist).
     """
 
     # The set of defined properties for the class
     _properties = frozenset(['provider', 'is_error'])
 
-    def __init__(self, *, provider: str = None, is_error: bool = None, **kwargs) -> None:
+    def __init__(
+        self,
+        *,
+        provider: Optional[str] = None,
+        is_error: Optional[bool] = None,
+        **kwargs,
+    ) -> None:
         """
         Initialize a DeleteTagResultsItem object.
 
@@ -948,15 +1113,19 @@ class DeleteTagsResult:
     """
     Results of deleting unattatched tags.
 
-    :attr int total_count: (optional) The number of tags that have been deleted.
-    :attr bool errors: (optional) It is set to true if there is at least one tag
+    :param int total_count: (optional) The number of tags that have been deleted.
+    :param bool errors: (optional) It is set to true if there is at least one tag
           operation in error.
-    :attr List[DeleteTagsResultItem] items: (optional) The list of tag operation
+    :param List[DeleteTagsResultItem] items: (optional) The list of tag operation
           results.
     """
 
     def __init__(
-        self, *, total_count: int = None, errors: bool = None, items: List['DeleteTagsResultItem'] = None
+        self,
+        *,
+        total_count: Optional[int] = None,
+        errors: Optional[bool] = None,
+        items: Optional[List['DeleteTagsResultItem']] = None,
     ) -> None:
         """
         Initialize a DeleteTagsResult object.
@@ -1029,11 +1198,16 @@ class DeleteTagsResultItem:
     """
     Result of a delete_tags request.
 
-    :attr str tag_name: (optional) The name of the deleted tag.
-    :attr bool is_error: (optional) true if the tag was not deleted.
+    :param str tag_name: (optional) The name of the deleted tag.
+    :param bool is_error: (optional) true if the tag was not deleted.
     """
 
-    def __init__(self, *, tag_name: str = None, is_error: bool = None) -> None:
+    def __init__(
+        self,
+        *,
+        tag_name: Optional[str] = None,
+        is_error: Optional[bool] = None,
+    ) -> None:
         """
         Initialize a DeleteTagsResultItem object.
 
@@ -1090,11 +1264,16 @@ class Resource:
     """
     A resource that might have tags that are attached.
 
-    :attr str resource_id: The CRN or IMS ID of the resource.
-    :attr str resource_type: (optional) The IMS resource type of the resource.
+    :param str resource_id: The CRN or IMS ID of the resource.
+    :param str resource_type: (optional) The IMS resource type of the resource.
     """
 
-    def __init__(self, resource_id: str, *, resource_type: str = None) -> None:
+    def __init__(
+        self,
+        resource_id: str,
+        *,
+        resource_type: Optional[str] = None,
+    ) -> None:
         """
         Initialize a Resource object.
 
@@ -1153,10 +1332,13 @@ class Tag:
     """
     A tag.
 
-    :attr str name: The name of the tag.
+    :param str name: The name of the tag.
     """
 
-    def __init__(self, name: str) -> None:
+    def __init__(
+        self,
+        name: str,
+    ) -> None:
         """
         Initialize a Tag object.
 
@@ -1209,15 +1391,20 @@ class TagList:
     """
     A list of tags.
 
-    :attr int total_count: (optional) Set the occurrences of the total tags that are
-          associated with this account.
-    :attr int offset: (optional) The offset at which tags are returned.
-    :attr int limit: (optional) The number of tags requested to be returned.
-    :attr List[Tag] items: (optional) Array of output results.
+    :param int total_count: (optional) Set the occurrences of the total tags that
+          are associated with this account.
+    :param int offset: (optional) The offset at which tags are returned.
+    :param int limit: (optional) The number of tags requested to be returned.
+    :param List[Tag] items: (optional) Array of output results.
     """
 
     def __init__(
-        self, *, total_count: int = None, offset: int = None, limit: int = None, items: List['Tag'] = None
+        self,
+        *,
+        total_count: Optional[int] = None,
+        offset: Optional[int] = None,
+        limit: Optional[int] = None,
+        items: Optional[List['Tag']] = None,
     ) -> None:
         """
         Initialize a TagList object.
@@ -1294,11 +1481,15 @@ class TagResults:
     """
     Results of an attach_tag or detach_tag request.
 
-    :attr List[TagResultsItem] results: (optional) Array of results of an attach_tag
-          or detach_tag request.
+    :param List[TagResultsItem] results: (optional) Array of results of an
+          attach_tag or detach_tag request.
     """
 
-    def __init__(self, *, results: List['TagResultsItem'] = None) -> None:
+    def __init__(
+        self,
+        *,
+        results: Optional[List['TagResultsItem']] = None,
+    ) -> None:
         """
         Initialize a TagResults object.
 
@@ -1356,12 +1547,17 @@ class TagResultsItem:
     """
     Result of an attach_tag or detach_tag request for a tagged resource.
 
-    :attr str resource_id: The CRN or IMS ID of the resource.
-    :attr bool is_error: (optional) It is `true` if the operation exits with an
+    :param str resource_id: The CRN or IMS ID of the resource.
+    :param bool is_error: (optional) It is `true` if the operation exits with an
           error.
     """
 
-    def __init__(self, resource_id: str, *, is_error: bool = None) -> None:
+    def __init__(
+        self,
+        resource_id: str,
+        *,
+        is_error: Optional[bool] = None,
+    ) -> None:
         """
         Initialize a TagResultsItem object.
 
